==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_entities/depreciation_001/ObjectFactory.java <==

package net.datastream.schemas.mp_entities.depreciation_001;

import javax.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.datastream.schemas.mp_entities.depreciation_001 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.datastream.schemas.mp_entities.depreciation_001
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link Depreciation }
     * 
     */
    public Depreciation createDepreciation() {
        return new Depreciation();
    }

    /**
     * Create an instance of {@link RemainingUsefulLife }
     * 
     */
    public RemainingUsefulLife createRemainingUsefulLife() {
        return new RemainingUsefulLife();
    }

    /**
     * Create an instance of {@link RelativeStartPeriod }
     * 
     */
    public RelativeStartPeriod createRelativeStartPeriod() {
        return new RelativeStartPeriod();
    }

    /**
     * Create an instance of {@link AdditionalDetails }
     * 
     */
    public AdditionalDetails createAdditionalDetails() {
        return new AdditionalDetails();
    }

}

==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_entities/depreciation_001/ObjectFactory.java <==

package net.datastream.schemas.mp_entities.depreciation_001;

import jakarta.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.datastream.schemas.mp_entities.depreciation_001 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.datastream.schemas.mp_entities.depreciation_001
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link Depreciation }
     * 
     * @return
     *     the new instance of {@link Depreciation }
     */
    public Depreciation createDepreciation() {
        return new Depreciation();
    }

    /**
     * Create an instance of {@link RemainingUsefulLife }
     * 
     * @return
     *     the new instance of {@link RemainingUsefulLife }
     */
    public RemainingUsefulLife createRemainingUsefulLife() {
        return new RemainingUsefulLife();
    }

    /**
     * Create an instance of {@link RelativeStartPeriod }
     * 
     * @return
     *     the new instance of {@link RelativeStartPeriod }
     */
    public RelativeStartPeriod createRelativeStartPeriod() {
        return new RelativeStartPeriod();
    }

    /**
     * Create an instance of {@link AdditionalDetails }
     * 
     * @return
     *     the new instance of {@link AdditionalDetails }
     */
    public AdditionalDetails createAdditionalDetails() {
        return new AdditionalDetails();
    }

}
